def slateblue():

    cor = 0x6A5ACD

    return cor

def slateblue1():

    cor = 0x836FFF

    return cor

def slateblue3():

    cor = 0x6959CD

    return cor

def darkslateblue():

    cor = 0x483D8B

    return cor

def midnightblue():

    cor = 0x191970

    return cor

def navy():

    cor = 0x000080

    return cor

def darkblue():

    cor = 0x00008B

    return cor

def mediumblue():

    cor = 0x0000CD

    return cor

def blue():

    cor = 0x0000FF

    return cor

def cornflowerblue():

    cor = 0x6495ED

    return cor

def royalblue():

    cor = 0x4169E1

    return cor

def dodgerblue():

    cor = 0x1E90FF

    return cor

def deepskyblue():

    cor = 0x00BFFF

    return cor

def lightskyblue():

    cor = 0x87CEFA

    return cor

def skyblue():

    cor = 0x87CEEB

    return cor

def lightblue():

    cor = 0xADD8E6

    return cor

def steelblue():

    cor = 0x4682B4

    return cor

def lightsteelblue():

    cor = 0xB0C4DE

    return cor

def slategray():

    cor = 0x708090

    return cor

def lightslategray():

    cor = 0x778899
    
    return cor


def darkslategreen():

    cor = 0x2F4F4F

    return cor

def mediumspringgreen():

    cor = 0x00FA9A

    return cor

def springgreen():

    cor = 0x00FF7F

    return cor

def palegreen():

    cor = 0x98FB98

    return cor

def lightgreen():

    cor = 0x90EE90

    return cor

def darkseagreen():

    cor = 0x8FBC8F

    return cor

def mediumseagreen():

    cor = 0x3CB371

    return cor

def seagreen():

    cor = 0x2E8B57

    return cor

def darkgreen():

    cor = 0x006400

    return cor

def green():

    cor = 0x008000

    return cor

def forestgreen():

    cor = 0x228B22

    return cor

def limegreen():

    cor = 0x32CD32

    return cor

def lime():

    cor = 0x00FF00

    return cor

def lawngreen():

    cor = 0x7CFC00

    return cor

def chartreuse():

    cor = 0x7FFF00

    return cor

def greenyellow():

    cor = 0xADFF2F

    return cor

def yellowgreen():

    cor = 0x9ACD32

    return cor

def olivedrab():

    cor = 0x6B8E23

    return cor

def darkolivegreen():

    cor = 0x556B2F

    return cor

def olive():

    cor = 0x808000

    return cor


import string

from .api import hexacolor, rgb, cmyk
from .str import stringcolor

def autodetect(args:str) -> str:

    if args[0] == '#':

        hexacolor(args)
    
    elif args[0] in list(string.ascii_letters):

        try:

            stringcolor(args)

        except:

            hexacolor(args)

    elif args.count(',') == 2:

        rgb(args)
    
    elif args.count(',') == 3:

        cmyk(args)

    else:

        print('ERROR: Not indentify the type')



from .colors.gray import *
from .colors.blue import *
from .colors.cyan import *
from .colors.brown import *
from .colors.purple import *
from .colors.pink import *
from .colors.green import *
from .colors.red import *
from .colors.orange import *
from .colors.yellow import *
from .colors.ligthcolors import *

def stringcolor(cor:str) -> str:

    if cor.lower().replace(' ','') == 'black': 

        color = black()

    elif cor.lower().replace(' ','') == 'gray1':

        color = grey11()
    
    elif cor.lower().replace(' ','') == 'gray2':

        color = grey21()
    
    elif cor.lower().replace(' ','') == 'gray3':

        color = grey31()
    
    elif cor.lower().replace(' ','') == 'dimgray': 

        color = dimgray()

    elif cor.lower().replace(' ','') == 'gray':

        color = gray()
    
    elif cor.lower().replace(' ','') == 'darkgray':

        color = darkgray()
    
    elif cor.lower().replace(' ','') == 'silver':

        color = silver()
    
    elif cor.lower().replace(' ','') == 'ligthgrey':

        color = ligthgrey()
    
    elif cor.lower().replace(' ','') == 'gainsboro':

        color = gainsboro()
    
    elif cor.lower().replace(' ','') == 'slateblue':

        color = slateblue()
    
    elif cor.lower().replace(' ','') == 'slateblue1': 

        color = slateblue1()

    elif cor.lower().replace(' ','') == 'slateblue2':

        color = slateblue3()
    
    elif cor.lower().replace(' ','') == 'darkslateblue':

        color = darkslateblue()
    
    elif cor.lower().replace(' ','') == 'midnightblue':

        color = midnightblue()
    
    elif cor.lower().replace(' ','') == 'navy':

        color = navy()
    
    elif cor.lower().replace(' ','') == 'darkblue':

        color = darkblue()
    
    elif cor.lower().replace(' ','') == 'mediumblue':

        color = mediumblue()
    
    elif cor.lower().replace(' ','') == 'blue': 

        color = blue()

    elif cor.lower().replace(' ','') == 'cornflowerblue':

        color = cornflowerblue()
    
    elif cor.lower().replace(' ','') == 'royalblue':

        color = royalblue()
    
    elif cor.lower().replace(' ','') == 'dodgerblue':

        color = dodgerblue()
    
    elif cor.lower().replace(' ','') == 'deepskyblue':

        color = deepskyblue()
    
    elif cor.lower().replace(' ','') == 'lightskyblue':

        color = lightskyblue()
    
    elif cor.lower().replace(' ','') == 'skyblue':

        color = skyblue()
    
    elif cor.lower().replace(' ','') == 'lightblue': 

        color = lightblue()

    elif cor.lower().replace(' ','') == 'steelblue':

        color = steelblue()
    
    elif cor.lower().replace(' ','') == 'lightsteelblue':

        color = lightsteelblue()
    
    elif cor.lower().replace(' ','') == 'slategray':

        color = slategray()
    
    elif cor.lower().replace(' ','') == 'lightslategray':

        color = lightslategray()
    
    elif cor.lower().replace(' ','') == 'cyan':

        color = cyan()
    
    elif cor.lower().replace(' ','') == 'darkturquoise':

        color = darkturquoise()
    
    elif cor.lower().replace(' ','') == 'turquoise': 

        color = turquoise()

    elif cor.lower().replace(' ','') == 'mediumturquoise':

        color = mediumturquoise()
    
    elif cor.lower().replace(' ','') == 'lightseagreen':

        color = lightseagreen()
    
    elif cor.lower().replace(' ','') == 'darkcyan':

        color = darkcyan()

    elif cor.lower().replace(' ','') == 'teal':

        color = teal()
    
    elif cor.lower().replace(' ','') == 'aquamarine':

        color = aquamarine()
    
    elif cor.lower().replace(' ','') == 'mediumaquamarine':

        color = mediumaquamarine()
    
    elif cor.lower().replace(' ','') == 'cadetblue': 

        color = cadetblue()

    elif cor.lower().replace(' ','') == 'darkkhaki':

        color = darkkhaki()
    
    elif cor.lower().replace(' ','') == 'goldenrod':

        color = goldenrod()
    
    elif cor.lower().replace(' ','') == 'darkgoldenrod':

        color = darkgoldenrod()

    elif cor.lower().replace(' ','') == 'saddlebrown':

        color = saddlebrown()
    
    elif cor.lower().replace(' ','') == 'sienna':

        color = sienna()
    
    elif cor.lower().replace(' ','') == 'rosybrown':

        color = rosybrown()
    
    elif cor.lower().replace(' ','') == 'peru': 

        color = peru()

    elif cor.lower().replace(' ','') == 'chocolate':

        color = chocolate()
    
    elif cor.lower().replace(' ','') == 'sandybrown':

        color = sandybrown()
    
    elif cor.lower().replace(' ','') == 'navajowhite':

        color = navajowhite()
    
    elif cor.lower().replace(' ','') == 'wheat':

        color = wheat()
    
    elif cor.lower().replace(' ','') == 'burlywood':

        color = burlywood()
    
    elif cor.lower().replace(' ','') == 'tan':

        color = tan()
    
    elif cor.lower().replace(' ','') == 'mediumslateBllue': 

        color = mediumslateBllue()

    elif cor.lower().replace(' ','') == 'mediumpurple':

        color = mediumpurple()
    
    elif cor.lower().replace(' ','') == 'blueviolet':

        color = blueviolet()
    
    elif cor.lower().replace(' ','') == 'indigo':

        color = indigo()
    
    elif cor.lower().replace(' ','') == 'darkviolet':

        color = darkviolet()
    
    elif cor.lower().replace(' ','') == 'darkorchid':

        color = darkorchid()
    
    elif cor.lower().replace(' ','') == 'mediumorchid':

        color = mediumorchid()
    
    elif cor.lower().replace(' ','') == 'purple': 

        color = purple()

    elif cor.lower().replace(' ','') == 'darkmagenta':

        color = darkmagenta()
    
    elif cor.lower().replace(' ','') == 'magenta':

        color = magenta()
    
    elif cor.lower().replace(' ','') == 'violet':

        color = violet()
    
    elif cor.lower().replace(' ','') == 'orchid':

        color = orchid()
    
    elif cor.lower().replace(' ','') == 'plum':

        color = plum()
    
    elif cor.lower().replace(' ','') == 'mediumvioletred':

        color = mediumvioletred()
    
    elif cor.lower().replace(' ','') == 'deeppink': 

        color = deeppink()

    elif cor.lower().replace(' ','') == 'hotpink':

        color = hotpink()
    
    elif cor.lower().replace(' ','') == 'palevioletred':

        color = palevioletred()
    
    elif cor.lower().replace(' ','') == 'lightpink':

        color = lightpink()
    
    elif cor.lower().replace(' ','') == 'pink':

        color = pink()
    
    elif cor.lower().replace(' ','') == 'lightcoral':

        color = lightcoral()
    
    elif cor.lower().replace(' ','') == 'indianred':

        color = indianred()
    
    elif cor.lower().replace(' ','') == 'crimson': 

        color = crimson()

    elif cor.lower().replace(' ','') == 'darkslategreen':

        color = darkslategreen()
    
    elif cor.lower().replace(' ','') == 'mediumspringgreen':

        color = mediumspringgreen()
    
    elif cor.lower().replace(' ','') == 'springgreen':

        color = springgreen()
    
    elif cor.lower().replace(' ','') == 'palegreen':

        color = palegreen()
    
    elif cor.lower().replace(' ','') == 'lightgreen':

        color = lightgreen()
    
    elif cor.lower().replace(' ','') == 'darkseagreen':

        color = darkseagreen()
    
    elif cor.lower().replace(' ','') == 'mediumseagreen': 

        color = mediumseagreen()

    elif cor.lower().replace(' ','') == 'seagreen':

        color = seagreen()
    
    elif cor.lower().replace(' ','') == 'darkgreen':

        color = darkgreen()
    
    elif cor.lower().replace(' ','') == 'green':

        color = green()

    elif cor.lower().replace(' ','') == 'forestgreen':

        color = forestgreen()
    
    elif cor.lower().replace(' ','') == 'limegreen':

        color = limegreen()
    
    elif cor.lower().replace(' ','') == 'lime':

        color = lime()
    
    elif cor.lower().replace(' ','') == 'lawngreen': 

        color = lawngreen()

    elif cor.lower().replace(' ','') == 'chartreuse':

        color = chartreuse()
    
    elif cor.lower().replace(' ','') == 'greenyellow':

        color = greenyellow()
    
    elif cor.lower().replace(' ','') == 'yellowgreen':

        color = yellowgreen()

    elif cor.lower().replace(' ','') == 'olivedrab':

        color = olivedrab()
    
    elif cor.lower().replace(' ','') == 'darkolivegreen':

        color = darkolivegreen()
    
    elif cor.lower().replace(' ','') == 'olive':

        color = olive()
    
    elif cor.lower().replace(' ','') == 'maroon': 

        color = maroon()

    elif cor.lower().replace(' ','') == 'darkred':

        color = darkred()
    
    elif cor.lower().replace(' ','') == 'firebrick':

        color = firebrick()
    
    elif cor.lower().replace(' ','') == 'brown':

        color = brown() 
    
    elif cor.lower().replace(' ','') == 'salmon':

        color = salmon()
    
    elif cor.lower().replace(' ','') == 'darksalmon':

        color = darksalmon()
    
    elif cor.lower().replace(' ','') == 'lightsalmon':

        color = lightsalmon()
    
    elif cor.lower().replace(' ','') == 'coral': 

        color = coral()

    elif cor.lower().replace(' ','') == 'tomato':

        color = tomato()
    
    elif cor.lower().replace(' ','') == 'red':

        color = red()
    
    elif cor.lower().replace(' ','') == 'orangered':

        color = orangered()
    
    elif cor.lower().replace(' ','') == 'darkorange':

        color = darkorange()
    
    elif cor.lower().replace(' ','') == 'orange':

        color = orange()
    
    elif cor.lower().replace(' ','') == 'gold':

        color = gold()
    
    elif cor.lower().replace(' ','') == 'yellow': 

        color = yellow()

    elif cor.lower().replace(' ','') == 'khaki':

        color = khaki()
    
    elif cor.lower().replace(' ','') == 'white': 

        color = white()

    elif cor.lower().replace(' ','') == 'aliceblue':

        color = aliceblue()
    
    elif cor.lower().replace(' ','') == 'ghostwhite':

        color = ghostwhite()
    
    elif cor.lower().replace(' ','') == 'snow':

        color = snow()
    
    elif cor.lower().replace(' ','') == 'seashell':

        color = seashell()
    
    elif cor.lower().replace(' ','') == 'floralwhite':

        color = floralwhite()
    
    elif cor.lower().replace(' ','') == 'whitesmoke':

        color = whitesmoke()
    
    elif cor.lower().replace(' ','') == 'beige': 

        color = beige()

    elif cor.lower().replace(' ','') == 'oldlace':

        color = oldlace()
    
    elif cor.lower().replace(' ','') == 'ivory':

        color = ivory()
    
    elif cor.lower().replace(' ','') == 'linen':

        color = linen()
    
    elif cor.lower().replace(' ','') == 'cornsilk':

        color = cornsilk()
    
    elif cor.lower().replace(' ','') == 'antiquewhite':

        color = antiquewhite()
    
    elif cor.lower().replace(' ','') == 'blanchedalmond':

        color = blanchedalmond()
    
    elif cor.lower().replace(' ','') == 'bisque': 

        color = bisque()

    elif cor.lower().replace(' ','') == 'lightyellow':

        color = lightyellow()
    
    elif cor.lower().replace(' ','') == 'lemonchiffon':

        color = lemonchiffon()
    
    elif cor.lower().replace(' ','') == 'lightgoldenrodyellow':

        color = lightgoldenrodyellow()

    elif cor.lower().replace(' ','') == 'papayawhip':

        color = papayawhip()
    
    elif cor.lower().replace(' ','') == 'peachpuff':

        color = peachpuff()
    
    elif cor.lower().replace(' ','') == 'moccasin':

        color = moccasin()
    
    elif cor.lower().replace(' ','') == 'palegoldenrod': 

        color = palegoldenrod()

    elif cor.lower().replace(' ','') == 'mistyrose':

        color = mistyrose()
    
    elif cor.lower().replace(' ','') == 'lavenderblush':

        color = lavenderblush()
    
    elif cor.lower().replace(' ','') == 'lavender':

        color = lavender()

    elif cor.lower().replace(' ','') == 'thistle':

        color = thistle()
    
    elif cor.lower().replace(' ','') == 'azure':

        color = azure()
    
    elif cor.lower().replace(' ','') == 'lightcyan':

        color = lightcyan()
    
    elif cor.lower().replace(' ','') == 'powderblue': 

        color = powderblue()

    elif cor.lower().replace(' ','') == 'paleturquoise':

        color = paleturquoise()
    
    elif cor.lower().replace(' ','') == 'honeydew':

        color = honeydew()
    
    elif cor.lower().replace(' ','') == 'mintcream':

        color = mintcream()

    return color


def mediumslateBllue():

    cor = 0x7B68EE

    return cor

def mediumpurple():

    cor = 0x9370DB

    return cor

def blueviolet():

    cor = 0x8A2BE2

    return cor

def indigo():

    cor = 0x4B0082

    return cor

def darkviolet():

    cor = 0x9400D3

    return cor

def darkorchid():

    cor = 0x9932CC

    return cor

def mediumorchid():

    cor = 0xBA55D3

    return cor

def purple():

    cor = 0xA020F0

    return cor

def darkmagenta():

    cor = 0x8B008B

    return cor

def magenta():

    cor = 0xFF00FF

    return cor

def violet():

    cor = 0xEE82EE

    return cor

def orchid():

    cor = 0xDA70D6

    return cor

def plum():

    cor = 0xDDA0DD

    return cor


def darkkhaki():

    cor = 0xBDB76B

    return cor

def goldenrod():

    cor = 0xDAA520

    return cor

def darkgoldenrod():

    cor = 0xB8860B

    return cor

def saddlebrown():

    cor = 0x8B4513

    return cor

def sienna():

    cor = 0xA0522D

    return cor

def rosybrown():

    cor = 0xBC8F8F

    return cor

def peru():

    cor = 0xCD853F

    return cor

def chocolate():

    cor = 0xD2691E

    return cor

def sandybrown():

    cor = 0xF4A460

    return cor

def navajowhite():

    cor = 0xFFDEAD

    return cor

def wheat():

    cor = 0xF5DEB3

    return cor

def burlywood():

    cor = 0xDEB887

    return cor

def tan():

    cor = 0xD2B48C

    return cor


from setuptools import setup

with open("README.md", "r") as f:

    long_description = f.read()

setup(
    name="hexacolors",
    version="0.3.9b",
    url = 'https://github.com/Marciel404/hexacolors',
    author="Marciel404",
    description='''
A simple library that converts string to hexadecimal understandable by python

A simple library that converts RGB to hexadecimal understandable by python

A simple library that converts CMYK to hexadecimal understandable by python

A simple library that converts hexadecimal understandable by python
''',
    long_description=long_description,
    long_description_content_type="text/markdown",
    packages=["hexacolors","hexacolors.colors"],
    license = 'MIT',
    keywords = 'String hexadecimal converter' ,
    CLASSIFIERS = [
    'Intended Audience :: Developers',
    'Topic :: colors',
    'License :: MIT License',
    'Programming Language :: Python',
    'Programming Language :: Python :: 3',
    'Programming Language :: Python :: 3.3',
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    ],
    python_requires='>=3.8',
    install_requires=['requests>=2.28.1'],
    dependency_links=['https://github.com/Marciel404/hexacolors']
)


def mediumvioletred():

    cor = 0xC71585

    return cor

def deeppink():

    cor = 0xFF1493

    return cor

def hotpink():

    cor = 0xFF69B4

    return cor

def palevioletred():

    cor = 0xDB7093

    return cor

def lightpink():

    cor = 0xFFB6C1

    return cor

def pink():

    cor = 0xFFC0CB

    return cor

def lightcoral():

    cor = 0xF08080

    return cor

def indianred():

    cor = 0xCD5C5C

    return cor

def crimson():

    cor = 0xDC143C

    return cor


"""
hexacolors
~~~~~~~~~~~~~~~~~~~

A simple library that converts string to hexadecimal understandable by python

A simple library that converts RGB to hexadecimal understandable by python

A simple library that converts CMYK to hexadecimal understandable by python

A simple library that converts hexadecimal understandable by python

:(c) 2022-present Marciel404
:license: MIT, see LICENSE for more details.

I created this library more to use as pycord integration

Using StringColor:

    >>> import hexacolors
    >>>
    >>> hexacolors.stringcolor('Blue')
    >>>
    >>> print(hexacolors.listall) #List all colors availables

Using HexaColor:

    >>> import hexacolors
    >>>
    >>> hexacolors.hexacolor('#0000FF') #Convert Hexadecimal Color for Python understand

Using rgb:

    >>> import hexacolors
    >>>
    >>> hexacolors.rgb('255,255,255')

Using cmyk:

    >>> import hexacolors
    >>>
    >>> hexacolors.cmyk('423,522,4,244')

Using AutoDetect:

    >>> import hexacolors
    >>>
    >>> hexacolors.autodetect('Blue') #Identify string
    >>>
    >>> hexacolors.autodetect('#fff000') #Identify Hexadecimal
    >>>
    >>> hexacolors.autodetect('255,255,255') #Identify RGB
    >>>
    >>> hexacolors.autodetect('423,522,4,244') #Identify CMYK

"""

__title__ = "Hexacolors"
__author__ = "Marciel404"
__license__ = "MIT"
__copyright__ = "2022-present Marciel404"
__version__ = "0.3.9b"

__path__ = __import__("pkgutil").extend_path(__path__, __name__)

from .str import stringcolor
from .api import hexacolor, rgb, cmyk
from .autodetect import autodetect

from .listcolors import (
    listblack,
    listblue,
    listcyan,
    listgreen,
    listbrown,
    listpurple,
    listpink,
    listred,
    listorange,
    listyellow,
    listlight,
    listall
    )


import requests

def hexacolor(hexa:str) -> str:

    if hexa[0] == '#':

        hexa = hexa[1::]

    p = requests.get(f'https://www.thecolorapi.com/id?hex={hexa}')

    colour = int(f"0x{p.json()['hex']['clean']}",16)

    return colour

def rgb(rgb:str) -> str:

    p = requests.get(f'https://www.thecolorapi.com/id?rgb={rgb}')

    colour = int(f"0x{p.json()['hex']['clean']}",16)

    return colour

def cmyk(cmyk:str) -> str:

    p = requests.get(f'https://www.thecolorapi.com/id?cmyk={cmyk}')

    colour = int(f"0x{p.json()['hex']['clean']}",16)

    return colour